
local folder, core = ...
local activeTab = activeTab

IT.MainFrame 				= CreateFrame("Frame","ImprovedTradechatFrame",UIParent)


IT.MainFrame:RegisterEvent("PLAYER_LOGIN") 
IT.MainFrame:SetScript("OnEvent",function(self,event)
	if event=="PLAYER_LOGIN" then
		IT.BuildFrame()
		IT.UpdateTabGroup(IT.TabGroup)
	end
end)

--[[---------------------------------------- 
-------------  Functions  ------------------
----------------------------------------]]--
function IT.UpdateTabGroup(t) 
	for k, v in pairs(t.Tab) do 
		if v ~= activeTab then 
			t.Tab[k].texture:SetTexture(.4,.4,.4,1)
			if t.Children[k] then 
				for a, b in pairs(t.Children[k]) do 
					if b:IsVisible() then 
						b:Hide()
					end
				end 
			end
		else 
			if t.Children[k] then 
				for a, b in pairs(t.Children[k]) do 
					if not b:IsVisible() then 
						b:Show()
					end
				end 
			end
		end 
	end 
end 

function IT.EnableMoving(frame)
	local OnDragStart = function(self, button)
		if button == "LeftButton" then
			self:StartMoving()
			self.isMoving = true
			self.hasMoved = false
		end
	end
	local function OnDragStop(self)
		if ( self.isMoving ) then
			self:StopMovingOrSizing();
			self.isMoving = false;
			self.hasMoved = true;
		end
	end
	local function OnHide(self)       
		if ( self.isMoving ) then
			self:StopMovingOrSizing();
			self.isMoving = false;
		end
	end
	frame:RegisterForDrag("LeftButton","RightButton");
	frame:EnableMouse(true);
	frame:SetMovable(true);
	frame:SetScript("OnDragStart",OnDragStart);
	frame:SetScript("OnDragStop",OnDragStop);
	frame:SetScript("OnHide",OnHide);
end 
function IT.ButtonOnEnter(self)
	if activeTab ~= self then 
		self.texture:SetTexture(.5,.5,.5,1)
	end
end 

function IT.ButtonOnLeave(self)
	if activeTab ~= self then 
		self.texture:SetTexture(.4,.4,.4,1)
	end
end 

function IT.ButtonSetActive(self)
	if activeTab ~= self then 
		activeTab = self
		self.texture:SetTexture(.25,.25,.25,1) 
		IT.UpdateTabGroup(IT.TabGroup)
	end 
end 

function IT.NewButton(w,h,text,fontsize,name,parent,func,onenter,onleave)
	local button = CreateFrame("Button",name,parent)
	
	button:SetSize(w,h)
	button.texture = button:CreateTexture()
	button.texture:SetAllPoints(button) 
	button.texture:SetTexture(.4,.4,.4,1) 
	button:SetPoint("CENTER")

	button.text = button:CreateFontString(nil,"ARTWORK","GameFontNormal")
	button.text:SetPoint("CENTER")
	button.text:SetFont(button.text:GetFont(),fontsize)
	button.text:SetText(text)
	button.text:SetTextColor(1,1,1,1)

	button:SetScript("OnEnter",onenter or IT.ButtonOnEnter)
	button:SetScript("OnLeave",onleave or IT.ButtonOnLeave)
	button:SetScript("OnClick",func or function(self)	
	end) 
	
	return button
end 
--[[---------------------------------------- 
----------  Scroll Frame Update ------------
----------------------------------------]]--
function IT.ScrollFrameUpdate()
	local offset = FauxScrollFrame_GetOffset(IT.ScrollFrame)
	FauxScrollFrame_Update(IT.ScrollFrame, #IT.List, 6, 100)
	for i=1,6 do
		local idx = offset+i
		if idx<=#IT.List and IT.List[idx] ~= nil then
			local author, msg, elapsed = IT.List[idx][1], IT.List[idx][2], IT.List[idx][5]
		
			IT.Buttons[i].name:SetPoint("TOPLEFT",IT.Buttons[i],"TOPLEFT",3,0)
			IT.Buttons[i].name:SetTextColor(1,.82,0)
			IT.Buttons[i].name:SetText(author)
			
			IT.Buttons[i].elapsed:SetPoint("TOPRIGHT",IT.Buttons[i],"TOPRIGHT",-5,-2)
			IT.Buttons[i].elapsed:SetTextColor(1,1,1,.7)
			IT.Buttons[i].elapsed:SetText(elapsed)

			IT.Buttons[i].text:SetPoint("TOPLEFT",IT.Buttons[i],"TOPLEFT",3,-5.5)
			IT.Buttons[i].text:SetTextColor(1,.75,.75)
			IT.Buttons[i].text:AddMessage(msg)
			
			IT.Buttons[i].name:Show()
			IT.Buttons[i].elapsed:Show()
			IT.Buttons[i].text:Show()
		else
			IT.Buttons[i].text:Hide()
			IT.Buttons[i].name:Hide()
			IT.Buttons[i].elapsed:Hide()
		end
	end
end

--[[---------------------------------------- 
-------------  Build Frame -----------------
----------------------------------------]]--
	
function IT.BuildFrame()
	--[[---------------------------------------- 
	-------------  Main Frame ------------------
	----------------------------------------]]--
	IT.MainFrame:SetSize(640,480)
	IT.MainFrame:SetPoint("CENTER")
	IT.MainFrame:SetBackdrop({
			bgFile = "Interface/AddOns/"..folder.."/bg",
			tile = false, tileSize = 0, 
			insets = { left = 0, right = 0, top = 0, bottom = 0 }
	})
	IT.MainFrame:SetBackdropColor(.1,.1,.1,.9)
	IT.EnableMoving(IT.MainFrame)
	--[[---------------------------------------- 
	-------------- Close Button ----------------
	----------------------------------------]]--
	IT.CloseButton = IT.NewButton(80,20,IT.Locale["close"],14,nil,IT.MainFrame,
		function(self) IT.MainFrame:Hide() end 
	)
	IT.CloseButton:SetPoint("BOTTOMRIGHT",IT.MainFrame,"BOTTOMRIGHT",-15,10) 
	--[[----------------------------------------
	--------------- Tab Group ------------------
	----------------------------------------]]--
	IT.TabGroup = CreateFrame("Frame",nil,IT.MainFrame)
	IT.TabGroup:SetSize(610,390)
	IT.TabGroup:SetPoint("BOTTOM",0,40)
	IT.TabGroup:SetBackdrop({
			bgFile = "Interface/AddOns/"..folder.."/bg", 
			edgeFile = "Interface/AddOns/"..folder.."/bg",
			tile = false, tileSize = 0, edgeSize = 1, 
			insets = { left = 0, right = 0, top = 0, bottom = 0 }
	})
	IT.TabGroup:SetBackdropColor(.1,.1,.1,1)
	IT.TabGroup:SetBackdropBorderColor(.4,.4,.4,1)
	--[[----------------------------------------
	--------------- Tab Group ------------------
	----------------------------------------]]--
	------------------ 1 -----------------------
	IT.TabGroup.Tab = {}
	IT.TabGroup.Children = {}
	IT.TabGroup.Tab[1] = IT.NewButton(100,20,IT.Locale["tradechat"],14,nil,IT.MainFrame,IT.ButtonSetActive)
	IT.TabGroup.Tab[1]:SetPoint("BOTTOMLEFT",IT.TabGroup,"TOPLEFT",4,-1) 
	------------------ 2 -----------------------
	IT.TabGroup.Tab[2]  = IT.NewButton(125,20,IT.Locale["notification"],12,nil,IT.MainFrame,IT.ButtonSetActive)
	IT.TabGroup.Tab[2] :SetPoint("LEFT",IT.TabGroup.Tab[1] ,"RIGHT",6,0) 
	------------------ 3 -----------------------
	IT.TabGroup.Tab[3]  = IT.NewButton(65,20,IT.Locale["macros"],14,nil,IT.MainFrame,IT.ButtonSetActive)
	IT.TabGroup.Tab[3] :SetPoint("LEFT",IT.TabGroup.Tab[2] ,"RIGHT",6,0) 
	------------------ 4 -----------------------
	IT.TabGroup.Tab[4]  = IT.NewButton(100,20,IT.Locale["settings"],14,nil,IT.MainFrame,IT.ButtonSetActive)
	IT.TabGroup.Tab[4] :SetPoint("LEFT",IT.TabGroup.Tab[3] ,"RIGHT",6,0) 
	--[[---------------------------------------- 
	--------  Tradechat - Search Box  ----------
	----------------------------------------]]--
	IT.Search = CreateFrame("EditBox",nil,IT.TabGroup)
	IT.Search:SetSize(188,20)
	IT.Search:SetPoint("TOPLEFT",IT.TabGroup,"TOPLEFT",10,-30)
	IT.Search.texture = IT.Search:CreateTexture()
	IT.Search.texture:SetAllPoints(IT.Search) 
	IT.Search.texture:SetTexture(.3,.3,.3,1)
	IT.Search:SetAutoFocus(false)
	IT.Search:SetTextInsets(5,5,5,5)
	IT.Search:SetMaxLetters(100)
	IT.Search:SetFontObject("GameFontNormal")
	IT.Search:SetFont(IT.Search:GetFont(),10)
	IT.Search:SetTextColor(1,1,1,1)
	IT.Search:SetScript("OnEnterPressed",function(self,...)
		self:ClearFocus()
		IT.UpdateResults()
	end) 
	IT.Search:SetScript("OnEscapePressed",function(self,...)
		self:ClearFocus()
		IT.UpdateResults()
	end) 
	IT.Search:SetScript("OnTextChanged",IT.UpdateResults)
	IT.Search:SetScript("OnEditFocusLost",function(self,...)
		IT.UpdateResults()
	end) 
	IT.Search.Label = IT.Search:CreateFontString(nil,"ARTWORK","GameFontNormal")
	IT.Search.Label:SetPoint("TOPLEFT",IT.TabGroup,"TOPLEFT",10,-14)
	IT.Search.Label:SetText(SEARCH)
	IT.Search.Label:SetFont(IT.Search.Label:GetFont(),12)
	IT.Search.Label:SetTextColor(1,1,1,1)
	--[[---------------------------------------- 
	---------  Tradechat - Msg Frame  ----------
	----------------------------------------]]--
	IT.MessageFrame = CreateFrame("Frame",nil,IT.TabGroup)
	IT.MessageFrame:SetSize(590,295)
	IT.MessageFrame:SetPoint("BOTTOM",0,32)
	IT.MessageFrame:SetBackdrop({
			bgFile = "Interface/AddOns/"..folder.."/bg", 
			edgeFile = "Interface/AddOns/"..folder.."/bg",
			tile = false, tileSize = 0, edgeSize = 1, 
			insets = { left = 0, right = 0, top = 0, bottom = 0 }
	})
	IT.MessageFrame:SetBackdropColor(.15,.15,.15,1)
	IT.MessageFrame:SetBackdropBorderColor(.4,.4,.4,1)
	--[[---------------------------------------- 
	----------  Tradechat - Send Box  ----------
	----------------------------------------]]--
	IT.Send = CreateFrame("EditBox",nil,IT.TabGroup)
	IT.Send:SetSize(482,18)
	IT.Send:SetPoint("TOPLEFT",IT.MessageFrame,"BOTTOMLEFT",0,-6)
	IT.Send.texture = IT.Send:CreateTexture()
	IT.Send.texture:SetAllPoints(IT.Send) 
	IT.Send.texture:SetTexture(.3,.3,.3,1)
	IT.Send:SetAutoFocus(false)
	IT.Send:SetTextInsets(5,5,5,5)
	IT.Send:SetMaxLetters(100)
	IT.Send:SetFontObject("GameFontNormal")
	IT.Send:SetFont(IT.Send:GetFont(),10)
	IT.Send:SetTextColor(1,1,1,1)
	IT.Send:SetScript("OnEnterPressed",function(self,...)
		local index, text
		text = self:GetText()
		if text == nil or text == "" or text == " " then return end 
		index = GetChannelName(IT.Locale["TradechatChannelName"])
		if index ~= 0 then 
			SendChatMessage(text,"CHANNEL",nil,index)
		end 
		self:SetText("")
		self:ClearFocus()
	end) 
	IT.Send:SetScript("OnEscapePressed",function(self,...)
		self:SetText("")
		self:ClearFocus()
	end) 
	IT.Send:SetScript("OnTextChanged",IT.UpdateResults)
	IT.Send:SetScript("OnEditFocusLost",function(self,...)
	end) 
	--[[---------------------------------------- 
	---------  Send Macro Button   -------------
	----------------------------------------]]--
	IT.SendMacro = IT.NewButton(100,18,IT.Locale["sendmacro"],13,nil,IT.MessageFrame,
		function(self) end 
	)
	IT.SendMacro:SetPoint("LEFT",IT.Send,"RIGHT",8,0) 
	--[[---------------------------------------- 
	---------  Result-Scroll Frame -------------
	----------------------------------------]]--
	IT.ScrollFrame = CreateFrame("ScrollFrame","ImprovedTradechatScrollFrame",IT.MessageFrame,"FauxScrollFrameTemplate")
	IT.ScrollFrame:SetPoint("TOPLEFT",IT.MessageFrame,"TOPLEFT",0,-1)
	IT.ScrollFrame:SetPoint("BOTTOMRIGHT",IT.MessageFrame,"BOTTOMRIGHT",-24,1)
	IT.ScrollFrame:SetScript("OnShow",IT.ScrollFrameUpdate)
	IT.ScrollFrame:SetScript("OnVerticalScroll",function(self,offset)
		FauxScrollFrame_OnVerticalScroll(self,offset,100,IT.ScrollFrameUpdate)
	end)

	IT.Buttons = {}
	for i=1,6 do
		IT.Buttons[i] = CreateFrame("Button",nil,IT.MessageFrame)
		IT.Buttons[i]:SetFrameLevel(5)
		IT.Buttons[i]:SetSize(570,50)
		if i == 1 then 
			IT.Buttons[i]:SetPoint("TOPLEFT",IT.MessageFrame,"TOPLEFT",0,(-i+1)*50)	
		else
			IT.Buttons[i]:SetPoint("TOPLEFT",IT.MessageFrame,"TOPLEFT",0,(-i+1)*50-(-i+1))	
		end
		IT.Buttons[i]:SetBackdrop({
			bgFile = "Interface/AddOns/"..folder.."/bg",
			bgFile = "Interface/AddOns/"..folder.."/bg",
			edgeFile = "Interface/AddOns/"..folder.."/bg",
			tile = false, tileSize = 0, edgeSize = 1, 
			insets = { left = 0, right = 0, top = 0, bottom = 0 }
		})
		IT.Buttons[i]:SetBackdropColor(.1,.1,.1,1)
		IT.Buttons[i]:SetBackdropBorderColor(.4,.4,.4,1)

		IT.Buttons[i]:SetScript("OnEnter",function(self)
			self:SetBackdropColor(.2,.2,.2,1)
		end) 
		IT.Buttons[i]:SetScript("OnLeave",function(self)
			self:SetBackdropColor(.1,.1,.1,1)
		end)
		IT.Buttons[i].name = IT.Buttons[i]:CreateFontString(nil,"ARTWORK","GameFontHighlight")
		IT.Buttons[i].name:SetSize(80,50)
		IT.Buttons[i].name:SetJustifyV("TOP") 
		IT.Buttons[i].name:SetJustifyH("LEFT")
		IT.Buttons[i].name:SetFont(IT.Buttons[i].name:GetFont(),12) 
	
		IT.Buttons[i].elapsed = IT.Buttons[i]:CreateFontString(nil,"ARTWORK","GameFontHighlight")
		IT.Buttons[i].elapsed:SetSize(80,50) 
		IT.Buttons[i].elapsed:SetJustifyV("RIGHT") 
		IT.Buttons[i].elapsed:SetJustifyH("RIGHT")
		IT.Buttons[i].elapsed:SetFont(IT.Buttons[i].elapsed:GetFont(), 10)

		IT.Buttons[i].text = CreateFrame("ScrollingMessageFrame",nil, IT.Buttons[i])
		IT.Buttons[i].text:SetSize(470,40)
		IT.Buttons[i].text:SetPoint("LEFT") 
		IT.Buttons[i].text:SetFontObject("GameFontNormal")
		IT.Buttons[i].text:SetFont(IT.Buttons[i].text:GetFont(),10)
		IT.Buttons[i].text:SetTextColor(1, 1, 1, 1) 
		IT.Buttons[i].text:SetJustifyV("CENTER") 
		IT.Buttons[i].text:SetJustifyH("LEFT") 
		IT.Buttons[i].text:SetHyperlinksEnabled(true)
		IT.Buttons[i].text:SetFading(false)
		IT.Buttons[i].text:SetMaxLines(1)
		IT.Buttons[i].text:SetMovable(true)
		IT.Buttons[i].text:SetResizable(true)
		IT.Buttons[i].text:EnableMouse(true)
		IT.Buttons[i].text:SetScript("OnHyperlinkEnter", function(self)
			self:GetParent():SetBackdropColor(.2,.2,.2,1)
		end)
		IT.Buttons[i].text:SetScript("OnHyperlinkLeave", function(self)
			self:GetParent():SetBackdropColor(.1,.1,.1,1)
		end)
		IT.Buttons[i].text:SetScript("OnHyperlinkClick", function(self, linkData, link, button)
			SetItemRef(link, "", button, self);
		end)
		IT.Buttons[i].text:SetScript("OnEnter", function(self)
			self:GetParent():SetBackdropColor(.2,.2,.2,1)
		end)
		IT.Buttons[i].text:SetScript("OnLeave",function(self)
			self:GetParent():SetBackdropColor(.1,.1,.1,1)
		end)
	end

	--[[---------------------------------------- 
	--------------------------------------------
	----------------------------------------]]--
	
	
	-- Tradechat --
	IT.TabGroup.Children[1] = {
		IT.Search,
		IT.Search.Label,
		IT.MessageFrame,
		IT.Send,
	}
	IT.ButtonSetActive(IT.TabGroup.Tab[1])
	IT.MainFrame:Hide()
end






















